safpis package
==============

Submodules
----------

safpis.api module
-----------------

.. automodule:: safpis.api
   :members:
   :undoc-members:
   :show-inheritance:

safpis.cli module
-----------------

.. automodule:: safpis.cli
   :members:
   :undoc-members:
   :show-inheritance:

safpis.models module
--------------------

.. automodule:: safpis.models
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: safpis
   :members:
   :undoc-members:
   :show-inheritance:
